# Contributing a patch

1. Submit an issue describing your proposed change to the repo in question.
2. The repo owner will respond to your issue promptly.
3. If your proposed change is accepted, fork the desired repo, develop and test your code changes.
4. Ensure that your code adheres to the [Timeflux coding standards](https://doc.timeflux.io/latest/extending/best_practices.html).
5. Ensure that your code has an appropriate set of unit tests which all pass.
6. Submit a pull request.